options nocenter validvarname=any;

*---Read in space-delimited ascii file;

data one; infile 'C:\ageamarj08.dat' lrecl=22 missover DSD DLM=' ' print;
input
  CPUBID 
  Y2246600
  Y2246800
  Y2266000
;

  label CPUBID  = "PUBLIC ID NUMBER 2008";
  label Y2246600 = "R EVER USED MARIJUANA 2008";
  label Y2246800 = "AGE WHEN FIRST USED MARIJUANA 2008";
  label Y2266000 = "IDENTIFICATION CODE OF MOTHER 2008";

/*---------------------------------------------------------------------*
 *  Crosswalk for Reference number & Question name                     *
 *---------------------------------------------------------------------*
 * Uncomment and edit this RENAME statement to rename variables
 * for ease of use.  You may need to use  name literal strings
 * e.g.  'variable-name'n   to create valid SAS variable names, or 
 * alter variables similarly named across years.
 * This command does not guarentee uniqueness

 * See SAS documentation for use of name literals and use of the
 * VALIDVARNAME=ANY option.     
 *---------------------------------------------------------------------*/
  /* *start* */

* RENAME
  Y1980000 = 'PUB_CASEID_2008'n
  Y2246600 = 'YASR-24A_2008'n
  Y2246800 = 'YASR-25_2008'n
  Y2266000 = 'MOTHERID_2008'n
;
  /* *finish* */

intv2008=1;

proc sort; by CPUBID;


data two; infile 'C:\agemarj06.dat' lrecl=99 missover DSD DLM=' ' print;
input
  CPUBID
  PUBID
  C0005300
  C0005400
  C0005700
  C0011201
  C0011203
  C0011205
  C0011207
  C0011209
  C0011211
  C0011213
  C0733300
  C0945000
  C1140400
  C1370500
  C1592600
  C1933400
  C2472600
  C2770600
  C3050500
  C3370800
  Y0364900
  Y0658900
  Y0954900
  Y1168700
  Y1407900
  Y1659300
  Y1932500
;

  label CPUBID   = "ID CODE OF CHILD";
  label PUBID    = "ID CODE OF MOTHER OF CHILD";
  label C0005300 = "RACE OF CHILD (FROM MOTHERS SCREENER 79)";
  label C0005400 = "SEX OF CHILD";
  label C0005700 = "DATE OF BIRTH OF CHILD - YEAR";
  label C0011201 = "WAS CHILD INTERVWD AS YOUNG ADULT?";
  label C0011203 = "WAS CHILD INTERVIEWED AS YOUNG ADULT? 96";
  label C0011205 = "WAS CHILD INTERVWD AS YOUNG ADULT? 1998";
  label C0011207 = "WAS CHILD INTERVWD AS YOUNG ADULT? 2000";
  label C0011209 = "WAS CHILD INTERVWD AS YOUNG ADULT? 2002";
  label C0011211 = "WAS CHILD INTERVWD AS YOUNG ADULT? 2004";
  label C0011213 = "WAS CHILD INTERVWD AS YOUNG ADULT? 2006";
  label C0733300 = "RS AGE WHEN FIRST USED MARIJUANA";
  label C0945000 = "CHILD'S AGE WHEN HE 1ST USED MARIJUANA";
  label C1140400 = "CH'S AGE WHEN S/HE 1ST USED MARIJUANA-92";
  label C1370500 = "CH AGE WHEN S/HE 1ST USED MARIJUANA 94";
  label C1592600 = "CH AGE WHEN S/HE 1ST USED MARIJUANA 96";
  label C1933400 = "AGE WHEN CHILD 1ST USED MARIJUANA 1998";
  label C2472600 = "AGE WHEN CHILD 1ST USED MARIJUANA 2000";
  label C2770600 = "AGE WHEN CHILD 1ST USED MARIJUANA 2002";
  label C3050500 = "AGE WHEN CHILD 1ST USED MARIJUANA 2004";
  label C3370800 = "AGE WHEN CHILD 1ST USED MARIJUANA 2006";
  label Y0364900 = "AGE WHEN FIRST USED MARIJUANA         94";
  label Y0658900 = "AGE WHEN FIRST USED MARIJUANA         96";
  label Y0954900 = "AGE WHEN FIRST USED MARIJUANA 1998";
  label Y1168700 = "AGE WHEN FIRST USED MARIJUANA 2000";
  label Y1407900 = "AGE WHEN FIRST USED MARIJUANA 2002";
  label Y1659300 = "AGE WHEN FIRST USED MARIJUANA 2004";
  label Y1932500 = "AGE WHEN FIRST USED MARIJUANA 2006";

proc sort; by CPUBID;


data three; merge one two;
  by cpubid;

/*This syntax limits the pool of respondents to those ever interviewed as a Young Adult*/
if intv2008=1 or C0011201=1 or C0011203=1 or C0011205=1 or 
    C0011207=1 or C0011209=1 or C0011211=1 or C0011213=1;

proc sort; by PUBID;


data four; infile 'C:\mommarj06.dat' lrecl=44 missover DSD DLM=' ' print;
input
  PUBID 
  R0214700
  R0214800
  R1395100
  R1395400
  R2720800
  R2720900
  R3915000
  R3915100
  R5053100
  R5053200
  R6430400
  R6430500
;

  label PUBID    = "ID# (1-12686) 79";
  label R0214700 = "RACL/ETHNIC COHORT /SCRNR 79";
  label R0214800 = "SEX OF R 79";
  label R1395100 = "DRUG #TMS USE MARJ/HASH 84";
  label R1395400 = "DRUG AGE 1ST USED MARJ/HASH 84";
  label R2720800 = "DRUG #TMS USE MARJ/HASH LIFETIME 88";
  label R2720900 = "DRUG AGE 1ST USED MARJ/HASH 88";
  label R3915000 = "DRUG #TMS USE MARJ/HASH LIFE 92";
  label R3915100 = "DRUG AGE 1ST USED MARJ/HASH 92";
  label R5053100 = "TOT OCCASION R USE MARIJUANA 94";
  label R5053200 = "AGE 1ST TIME USED MARIJUANA 94";
  label R6430400 = "TOT OCCASION R USE MARIJUANA 1998";
  label R6430500 = "AGE 1ST TIME USED MARIJUANA 1998";

proc sort; by PUBID;

data five; merge three(in=ina) four;
  by pubid; if (ina);

  
/*Constructs age of mother at first marijuana use.  Uses oldest posible data, then fills forward.*/
momage=.;
if R1395400>0 then momage=R1395400; 
else if R2720900>0 then momage=R2720900;
else if R3915100>0 then momage=R3915100;
else if R5053200>0 then momage=R5053200;
else if R6430500>0 then momage=R6430500;


/*Constructs age of young adult at first marijuana use.  Uses oldest posible data, then fills forward.
  CSAS data filtered through first; any YA would have had the chance to answer this while
  still in the Child age reange.*/
yaage=.;
if C0733300>0 and C0733300<90 then yaage=C0733300;
else if C0945000>0 and C0945000<90 then yaage=C0945000;
else if C1140400>0 and C1140400<90 then yaage=C1140400;
else if C1370500>0 and C1370500<90 then yaage=C1370500;
else if C1592600>0 and C1592600<90 then yaage=C1592600;
else if C1933400>0 and C1933400<90 then yaage=C1933400;
else if C2472600>0 and C2472600<90 then yaage=C2472600;
else if C2770600>0 and C2770600<90 then yaage=C2770600;
else if C3050500>0 and C3050500<90 then yaage=C3050500;
else if C3370800>0 and C3370800<90 then yaage=C3370800;
else if Y0364900>0 and Y0364900<90 then yaage=Y0364900;
else if Y0658900>0 and Y0658900<90 then yaage=Y0658900;
else if Y0954900>0 and Y0954900<90 then yaage=Y0954900;
else if Y1168700>0 and Y1168700<90 then yaage=Y1168700;
else if Y1407900>0 and Y1407900<90 then yaage=Y1407900;
else if Y1659300>0 and Y1659300<90 then yaage=Y1659300;
else if Y1932500>0 and Y1932500<90 then yaage=Y1932500;
else if Y2246800>0 and Y2246800<90 then yaage=Y2246800;


/*Constructs yes/no variable for ever used marijuana for moms.  If mom has a valid age for first use of
  marijuana, code as yes.  If mom was interviewed in at least one year where one of these questions 
  were asked and has a valid skip for age, code as no.*/
momever=.;
if momage^=. then momever=1;
else if momage=. and (R1395400=-4 or R2720900=-4 or R3915100=-4 or R5053200=4 
        or R6430500=-4) then momever=0;


/*Constructs yes/no variable for ever used marijuana for YAs.  If YA has a valid age for first use of
  marijuana, code as yes.  If YA was interviewed in at least one year where one of these questions 
  were asked and has a valid skip for age, code as no.*/
yaever=.;
if yaage^=. then yaever=1;
else if yaage=. and (C0733300<-3 or C0945000<-3 or C1140400<-3 or C1370500<-3 or C1592600<-3 or 
         C1933400<-3 or C2472600<-3 or C2770600<-3 or C3050500<-3 or C3370800<-3 or Y0364900<-3 
         or Y0658900<-3 or Y0954900<-3 or Y1168700<-3 or Y1407900<-3 or Y1659300<-3 or 
         Y1932500<-3 or Y2246800<-3) then yaever=0;

proc format;
  value agesf
  0 - 9 = 'Less than 10 years old'
  10 - 14 = '10 to 14 years old'
  15 - 19 = '15 to 19 years old'
  20 - 24 = '20 to 24 years old'
  25 - high = '25 years or older';
  value racef
  1='Hispanic'
  2='Black'
  3='Non-Black, Non-Hispanic';
  value yesnof
  0 = 'No'
  1 = 'Yes';
  value genderf
  1 = 'Male'
  2 = 'Female';
  
proc freq; 
  tables momever momage  yaever yaage;
  format  momage yaage agesf.
          momever yaever yesnof.
          C0005300 racef.
          C0005400 genderf.;
title 'Basic Frequencies for ever used marijuana and age at first marijuana use for moms and YAs';
proc freq; 
  tables momever*yaever momage*yaage;
  format  momage yaage agesf.
          momever yaever yesnof.
          C0005300 racef.
          C0005400 genderf.;
title 'Crosstabs of ever used marijuana and age at first marijuana use for moms and YAs';
proc freq; 
  tables  C0005300*momever*yaever C0005300*momage*yaage;  
  format  momage yaage agesf.
          momever yaever yesnof.
          C0005300 racef.
          C0005400 genderf.;
title 'Crosstabs by race of ever used marijuana and age at first marijuana use for moms and YAs';
proc freq; 
  tables  C0005400*momever*yaever C0005400*momage*yaage;  
  format  momage yaage agesf.
          momever yaever yesnof.
          C0005300 racef.
          C0005400 genderf.;
title 'Crosstabs by gender of ever used marijuana and age at first marijuana use for moms and YAs';
run;
