options nocenter validvarname=any;

*---Read in space-delimited ascii file;

data new_data;


infile 'lintyear_intdate9394.dat' lrecl=97 missover DSD DLM=' ' print;
input
  R0000100
  R0214700
  R0214800
  R0406310
  R0618810
  R0898510
  R1144710
  R1519910
  R1890300
  R2257400
  R2444600
  R2870100
  R3073900
  R3400500
  R3655900
  R4006400
  R4100200
  R4100201
  R4100202
  R4417500
  R4500200
  R4500201
  R4500202
  R5080500
  R5165800
  R6478500
  R7006300
  R7703500
  R8495900
  T0987500
;
array nvarlist _numeric_;


*---Recode missing values to SAS custom system missing. See SAS
      documentation for use of MISSING option in procedures, e.g. PROC FREQ;

do over nvarlist;
  if nvarlist = -1 then nvarlist = .R;  /* Refused */
  if nvarlist = -2 then nvarlist = .D;  /* Dont know */
  if nvarlist = -3 then nvarlist = .I;  /* Invalid missing */
  if nvarlist = -4 then nvarlist = .V;  /* Valid missing */
  if nvarlist = -5 then nvarlist = .N;  /* Non-interview */
end;

  label R0000100 = "ID# (1-12686) 79";
  label R0214700 = "RACL/ETHNIC COHORT /SCRNR 79";
  label R0214800 = "SEX OF R 79";
  label R0406310 = "REASON FOR NONINT 80";
  label R0618810 = "REASON FOR NONINT 81";
  label R0898510 = "REASON FOR NONINT 82";
  label R1144710 = "REASON FOR NONINT 83";
  label R1519910 = "REASON FOR NONINT 84";
  label R1890300 = "REASON FOR NONINT 85";
  label R2257400 = "REASON FOR NONINT 86";
  label R2444600 = "REASON FOR NONINT 87";
  label R2870100 = "REASON FOR NONINT 88";
  label R3073900 = "REASON FOR NONINT 89";
  label R3400500 = "REASON FOR NONINT 90";
  label R3655900 = "REASON FOR NONINT 91";
  label R4006400 = "REASON FOR NONINT 92";
  label R4100200 = "DATE OF INTERVIEW 93:MO";
  label R4100201 = "DATE OF INTERVIEW 93:DY";
  label R4100202 = "DATE OF INTERVIEW 93:YR";
  label R4417500 = "REASONS FOR NON-INT 93";
  label R4500200 = "DATE OF INTERVIEW 94";
  label R4500201 = "DATE OF INTERVIEW 94";
  label R4500202 = "DATE OF INTERVIEW 94";
  label R5080500 = "REASONS FOR NON-INT 94";
  label R5165800 = "REASONS FOR NON-INT 96";
  label R6478500 = "REASONS FOR NON-INT 1998";
  label R7006300 = "REASONS FOR NON-INT 2000";
  label R7703500 = "REASONS FOR NON-INT 2002";
  label R8495900 = "REASONS FOR NON-INT 2004";
  label T0987500 = "REASONS FOR NON-INT 2006";

/*---------------------------------------------------------------------*
 *  Crosswalk for Reference number & Question name                     *
 *---------------------------------------------------------------------*
 * Uncomment and edit this RENAME statement to rename variables
 * for ease of use.  You may need to use  name literal strings
 * e.g.  'variable-name'n   to create valid SAS variable names, or 
 * alter variables similarly named across years.
 * This command does not guarentee uniqueness

 * See SAS documentation for use of name literals and use of the
 * VALIDVARNAME=ANY option.     
 *---------------------------------------------------------------------*/
  /* *start* */

* RENAME
  R0000100 = 'CASEID_1979'n
  R0214700 = '*Created_1979'n
  R0214800 = '*Created_1979'n
  R0406310 = '*Created_1980'n
  R0618810 = '*Created_1981'n
  R0898510 = '*Created_1982'n
  R1144710 = '*Created_1983'n
  R1519910 = '*Created_1984'n
  R1890300 = '*Created_1985'n
  R2257400 = '*Created_1986'n
  R2444600 = '*Created_1987'n
  R2870100 = '*Created_1988'n
  R3073900 = '*Created_1989'n
  R3400500 = '*Created_1990'n
  R3655900 = '*Created_1991'n
  R4006400 = '*Created_1992'n
  R4100200 = 'Q-1C_1993'n
  R4100201 = 'Q-1C_1993'n
  R4100202 = 'Q-1C_1993'n
  R4417500 = 'RNI_1993'n
  R4500200 = 'Q-1C~D_1994'n
  R4500201 = 'Q-1C~M_1994'n
  R4500202 = 'Q-1C~Y_1994'n
  R5080500 = 'RNI_1994'n
  R5165800 = 'RNI_1996'n
  R6478500 = 'RNI_1998'n
  R7006300 = 'RNI_2000'n
  R7703500 = 'RNI_2002'n
  R8495900 = 'RNI_2004'n
  T0987500 = 'RNI_2006'n
;
  /* *finish* */

run;

proc means data=new_data n mean min max;
run;


/*---------------------------------------------------------------------*
 *  FORMATTED TABULATIONS                                              *
 *---------------------------------------------------------------------*
 * You can uncomment and edit the PROC FORMAT and PROC FREQ statements 
 * provided below to obtain formatted tabulations. The tabulations 
 * should reflect codebook values.
 * 
 * Please edit the formats below reflect any renaming of the variables
 * you may have done in the first data step. 
 *---------------------------------------------------------------------*/

/*
proc format; 
*/

/* 
 *--- Tabulations using reference number variables;
proc freq data=new_data;
tables _ALL_ /MISSING;
run;
*/

/*
*--- Tabulations using default named variables;
proc freq data=new_data;
tables _ALL_ /MISSING;
run;
*/

